==> web-ha-3.1-b15-sources.jar: org/glassfish/web/ha/session/management/ModifiedHASession.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.web.ha.session.management;

import org.apache.catalina.Manager;

import javax.servlet.http.HttpSession;
import java.io.Serializable;

/**
 *
 * @author  lwhite
 * @author Rajiv Mordani
 */
public class ModifiedHASession extends BaseHASession 
    implements HttpSession, HASession, Serializable {

    private transient boolean _dirtyFlag = false;


    /** Creates a new instance of ModifiedHASession */
    public ModifiedHASession(Manager manager) {
        super(manager);
    }

    /**
     * set the attribute name to the value value
     * and update the dirty flag to true
     * @param name
     * @param value
     */     
    public void setAttribute(String name, Object value) { 
        super.setAttribute(name, value);
        this.setDirty(true);
    }

    /**
     * remove the attribute name
     * and update the dirty flag to true
     * @param name
     */     
    public void removeAttribute(String name) {
        super.removeAttribute(name);
        this.setDirty(true);
    }

    /**
     * return isDirty
     */     
    public boolean isDirty() {
        return _dirtyFlag;
    }
    
    /**
     * set isDirty
     * @param isDirty
     */      
    public void setDirty(boolean isDirty) {
        _dirtyFlag = isDirty;
    }

}

==> web-ha-3.2-b03-sources.jar: org/glassfish/web/ha/session/management/ModifiedHASession.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.web.ha.session.management;

import org.apache.catalina.Manager;

import javax.servlet.http.HttpSession;
import java.io.Serializable;

/**
 *
 * @author  lwhite
 * @author Rajiv Mordani
 */
public class ModifiedHASession extends BaseHASession 
    implements HttpSession, HASession, Serializable {

    private transient boolean dirtyFlag = false;


    /** Creates a new instance of ModifiedHASession */
    public ModifiedHASession(Manager manager) {
        super(manager);
    }

    /**
     * set the attribute name to the value value
     * and update the dirty flag to true
     * @param name
     * @param value
     */     
    public void setAttribute(String name, Object value) { 
        super.setAttribute(name, value);
        this.setDirty(true);
    }

    /**
     * remove the attribute name
     * and update the dirty flag to true
     * @param name
     */     
    public void removeAttribute(String name) {
        super.removeAttribute(name);
        this.setDirty(true);
    }

    /**
     * return isDirty
     */     
    public boolean isDirty() {
        return dirtyFlag;
    }
    
    /**
     * set isDirty
     * @param isDirty
     */      
    public void setDirty(boolean isDirty) {
        dirtyFlag = isDirty;
    }

}
